@@ -4,7 +4,6 @@ import os
 import magic
 
 from texta_parsers import exceptions
-from texta_parsers.email_parser import EmailParser
 
 
 class Extension:
@@ -51,6 +50,43 @@ class Extension:
             return False
         return False
 
+    @staticmethod
+    def _has_msg_mimetype(input):
+        mimetype = magic.from_buffer(input, mime=True)
+        return mimetype == "message/rfc822"
+
+
+    @staticmethod
+    def _begins_like_mbox(input):
+        try:
+            return input.decode().startswith("From ")
+        except:
+            return False
+
+    @staticmethod
+    def _try_get_file_beginning(file):
+        if isinstance(file, bytes):
+            return file[:2048]
+        else:
+            try:
+                return open(file, "rb").read(2048)
+            except:
+                return None
+
+    @staticmethod
+    def file_is_mail(filename):
+        file_beginning = Extension._try_get_file_beginning(filename)
+
+        ext = os.path.splitext(filename)[1]
+        if ext in Extension.EMAIL_EXTENSIONS:
+            return ext
+
+        if (file_beginning == None):
+            return None
+        elif (Extension._has_msg_mimetype(file_beginning)):
+            return ".eml"
+        elif (Extension._begins_like_mbox(file_beginning)):
+            return ".mbox"
 
     @staticmethod
     def predict(file, file_name=None):
@@ -75,9 +111,9 @@ class Extension:
         # try extracting extenion from file name
         _, ext = os.path.splitext(file_name)
         parsed_ext = ext.lower()
+
         # extra check for mail or mailbox files
-        file_beginning = EmailParser._try_get_file_beginning(file)
-        mail_ext = EmailParser._file_is_mail(file_name, file_beginning)
+        mail_ext = Extension.file_is_mail(file_name)
 
         # final call
         if mail_ext:
@@ -89,7 +125,7 @@ class Extension:
             guessed_known_exts = [ext for ext in guessed_extensions if ext in Extension.KNOWN_EXTENSIONS]
             predicted_ext = guessed_known_exts[0] if len(guessed_known_exts) > 0 else guessed_extensions[0]
 
-        if (predicted_ext not in Extension.KNOWN_EXTENSIONS):
-            raise exceptions.UnsupportedFileError("File type not supported.")
+        #if (predicted_ext not in Extension.KNOWN_EXTENSIONS):
+        #    raise exceptions.UnsupportedFileError("File type not supported.")
 
         return predicted_ext
